summaryrefslogtreecommitdiffstats
path: root/chromeos/login
diff options
context:
space:
mode:
authortreib@chromium.org <treib@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-18 13:26:57 +0000
committertreib@chromium.org <treib@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-18 13:26:57 +0000
commit933cc2e2d4f2335ffec0a90ddf714f5ef416c78f (patch)
tree00f7f35568d1e8e128306a003b8f19249784c530 /chromeos/login
parent5c277ba487161758226fa835eacb00d55322dad5 (diff)
downloadchromium_src-933cc2e2d4f2335ffec0a90ddf714f5ef416c78f.zip
chromium_src-933cc2e2d4f2335ffec0a90ddf714f5ef416c78f.tar.gz
chromium_src-933cc2e2d4f2335ffec0a90ddf714f5ef416c78f.tar.bz2
Rename "managed (mode|user)" to "supervised user" (part 7)
Followup to https://codereview.chromium.org/384023002/ This CL renames ChromeOS-specific code. Still missing: - ChromeOS-specific resource IDs (strings and images) - JavaScript, HTML, CSS - The global ENABLE_MANAGED_USERS define TBR=atwilson@chromium.org (c/b/signin) TBR=nkostylev@chromium.org (c/b/chromeos) TBR=noms@chromium.org (c/b/profiles) TBR=oshima@chromium.org (ash and c/b/ui/ash) All TBRs are simple renamings. BUG=385113 Review URL: https://codereview.chromium.org/393343002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@284078 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chromeos/login')
-rw-r--r--chromeos/login/login_state.cc4
-rw-r--r--chromeos/login/login_state.h4
-rw-r--r--chromeos/login/user_names.cc2
-rw-r--r--chromeos/login/user_names.h4
4 files changed, 7 insertions, 7 deletions
diff --git a/chromeos/login/login_state.cc b/chromeos/login/login_state.cc
index 14dbce9..eba009a 100644
--- a/chromeos/login/login_state.cc
+++ b/chromeos/login/login_state.cc
@@ -99,7 +99,7 @@ bool LoginState::IsGuestUser() const {
case LOGGED_IN_USER_NONE:
case LOGGED_IN_USER_REGULAR:
case LOGGED_IN_USER_OWNER:
- case LOGGED_IN_USER_LOCALLY_MANAGED:
+ case LOGGED_IN_USER_SUPERVISED:
case LOGGED_IN_USER_KIOSK_APP:
return false;
case LOGGED_IN_USER_GUEST:
@@ -125,7 +125,7 @@ bool LoginState::UserHasNetworkProfile() const {
bool LoginState::IsUserAuthenticated() const {
return logged_in_user_type_ == LOGGED_IN_USER_REGULAR ||
logged_in_user_type_ == LOGGED_IN_USER_OWNER ||
- logged_in_user_type_ == LOGGED_IN_USER_LOCALLY_MANAGED;
+ logged_in_user_type_ == LOGGED_IN_USER_SUPERVISED;
}
bool LoginState::IsUserGaiaAuthenticated() const {
diff --git a/chromeos/login/user_names.cc b/chromeos/login/user_names.cc
index f8964f9..df3be0f 100644
--- a/chromeos/login/user_names.cc
+++ b/chromeos/login/user_names.cc
@@ -16,7 +16,7 @@ const char* kSignInUser = "sign-in-user-id";
// Should match cros constant in platform/libchromeos/chromeos/cryptohome.h
const char* kGuestUserName = "$guest";
-const char* kLocallyManagedUserDomain = "locally-managed.localhost";
+const char* kSupervisedUserDomain = "locally-managed.localhost";
const char* kRetailModeUserName = "demouser@";
diff --git a/chromeos/login/login_state.h b/chromeos/login/login_state.h
index 5f60f63..7ab7666 100644
--- a/chromeos/login/login_state.h
+++ b/chromeos/login/login_state.h
@@ -27,7 +27,7 @@ class CHROMEOS_EXPORT LoginState {
LOGGED_IN_USER_GUEST, // A guest is logged in (i.e. incognito)
LOGGED_IN_USER_RETAIL_MODE, // Is in retail mode
LOGGED_IN_USER_PUBLIC_ACCOUNT, // A public account is logged in
- LOGGED_IN_USER_LOCALLY_MANAGED, // A locally managed user is logged in
+ LOGGED_IN_USER_SUPERVISED, // A supervised user is logged in
LOGGED_IN_USER_KIOSK_APP // Is in kiosk app mode
};
@@ -85,7 +85,7 @@ class CHROMEOS_EXPORT LoginState {
bool IsUserAuthenticated() const;
// Returns true if the user is authenticated by logging into Google account
// (i.e., non public nor locally managed account).
bool IsUserGaiaAuthenticated() const;
void set_always_logged_in(bool always_logged_in) {
@@ -85,7 +85,7 @@ class CHROMEOS_EXPORT LoginState {
bool IsUserAuthenticated() const;
// Returns true if the user is authenticated by logging into Google account
- // (i.e., non public nor locally managed account).
+ // (i.e., non public nor supervised account).
bool IsUserGaiaAuthenticated() const;
void set_always_logged_in(bool always_logged_in) {
diff --git a/chromeos/login/user_names.h b/chromeos/login/user_names.h
index 4c296f7..41bdff0 100644
--- a/chromeos/login/user_names.h
+++ b/chromeos/login/user_names.h
@@ -27,8 +27,8 @@ CHROMEOS_EXPORT extern const char* kSignInUser;
// Username for Guest session user.
CHROMEOS_EXPORT extern const char* kGuestUserName;
-// Domain that is used for all locally managed users.
-CHROMEOS_EXPORT extern const char* kLocallyManagedUserDomain;
+// Domain that is used for all supervised users.
+CHROMEOS_EXPORT extern const char* kSupervisedUserDomain;
// The retail mode user has a magic, domainless e-mail address.
CHROMEOS_EXPORT extern const char* kRetailModeUserName;